Instruction:
According to the requirements described in the Requirement section, extract the complete relevant tables from the Raw Content.
Note that when constructing the table, you should include the table title and source information, such as which company's report the table comes from.
First, identify the keywords in the Requirement, including entity names and attribute names, and then use these keywords to extract information from the Raw Content. If the Raw
Content does not contain the information required by the Requirement, extract only a small amount of information that is most relevant to the Requirement.
When analyzing the Requirement and extracting from the Raw Content, do not translate; maintain the original language.
Examples:
########
|Broadway Financial Corporation and Subsidiary|\n|---|\n|**Consolidated Statements of Financial Condition**|\n|**In thousands, except share and per share amounts**|\n|**Assets**|\n|Cash and due from banks|$
6,037|\n|Interest-bearing deposits in other banks|$ 61,085|\n|Cash and cash equivalents|$ 67,122|\n|Securities available-for-sale, at fair value|$ 293,243|\n|Loans receivable held for investment, net of allowance of
$7,552 and $7,348|$ 926,497|\n|Accrued interest receivable|$ 5,638|\n|Federal Home Loan Bank (“FHLB”) stock|$ 10,292|\n|Federal Reserve Bank (“FRB”) stock|$ 3,543|\n|Office properties and equipment, net|$
9,731|\n|Bank owned life insurance, net|$ 3,286|\n|Deferred tax assets, net|$ 9,827|\n|Core deposit intangible, net|$ 2,027|\n|Goodwill|$ 25,858|\n|Other assets|$ 13,400|\n|Total assets|$ 1,370,464|
########
Raw Documents:
{{documents}}
Query:
{{query}}
Output: